return function()
	local circle = love.graphics.newCanvas(love.graphics.getWidth()/6,love.graphics.getWidth()/6)
	love.graphics.setCanvas(circle)
	love.graphics.circle("fill", love.graphics.getWidth()/12, love.graphics.getWidth()/12, love.graphics.getWidth()/12)
	love.graphics.setCanvas()

	local shader = love.graphics.newShader([[
		vec4 effect(vec4 color, Image texture, vec2 texture_coords, vec2 screen_coords) {
			if (Texel(texture, texture_coords).a == .0) {
				// a discarded pixel wont be applied as the stencil.
				discard;
			}
		return vec4(1.0);
	}]])

	local partSysL = love.graphics.newParticleSystem(circle, 50)
	partSysL:setAreaSpread("uniform", 20,20)
	partSysL:setSizes(0,1)
	partSysL:setParticleLifetime(2, 3)
	partSysL:setEmissionRate(20)
	partSysL:setSizes(0,0.5,0)
	partSysL:setSizeVariation(0)
	partSysL:setLinearAcceleration(0,-250,100,-250)
	local partSysR = love.graphics.newParticleSystem(circle, 50)
	partSysR:setAreaSpread("uniform", 20,20)
	partSysR:setSizes(0,1)
	partSysR:setParticleLifetime(2, 3)
	partSysR:setEmissionRate(20)
	partSysR:setSizes(0,0.5,0)
	partSysR:setSizeVariation(0)
	partSysR:setLinearAcceleration(-100,-250,0,-250)
	local partSysT = love.graphics.newParticleSystem(circle, 50)
	partSysT:setAreaSpread("uniform", 15,15)
	partSysT:setSizes(0,.5)
	partSysT:setParticleLifetime(1,3)
	partSysT:setEmissionRate(10)
	partSysT:setSizeVariation(0)
	partSysT:setLinearAcceleration(-50,-300,50,-300)
	local partSysF = love.graphics.newParticleSystem(circle, 30)
	partSysF:setAreaSpread("uniform", 10,10)
	partSysF:setSizes(150/(love.graphics.getWidth()/6),150/(love.graphics.getWidth()/6))
	partSysF:setParticleLifetime(1,1.5)
	partSysF:setEmissionRate(10)
	partSysF:setSizeVariation(0)
	partSysF:setSizes(1,0)
	partSysF:setLinearAcceleration(0,-300,0,-300)

	local fireCanvas = love.graphics.newCanvas(240, 6*love.graphics.getHeight()/8+20)

	return {
		update = function(dt)
			partSysL:update(dt)
			partSysR:update(dt)
			partSysT:update(dt*2)
			partSysF:update(dt)
		end,
		draw = function(x,y, color)
			x, y = x or 0, y or 0
			x,y = x - fireCanvas:getWidth()/2, y - fireCanvas:getHeight()*.8
			love.graphics.setCanvas(fireCanvas)
			love.graphics.clear()
			love.graphics.stencil(function()
				love.graphics.setShader(shader)
				love.graphics.draw(partSysL, 20, 3*love.graphics.getHeight()/4)
				love.graphics.draw(partSysR, 200, 3*love.graphics.getHeight()/4)
				love.graphics.draw(partSysT, 110, 3*love.graphics.getHeight()/4-90)
				love.graphics.setShader()
			end, "replace", 1)
			love.graphics.setStencilTest("less", 1)
			love.graphics.rectangle("fill", 0, 0, 240, 6*love.graphics.getHeight()/8+20)
			love.graphics.setStencilTest()
		love.graphics.setCanvas()
		love.graphics.stencil(function()
			love.graphics.setShader(shader)
			love.graphics.draw(partSysF, 110 + x, 6*love.graphics.getHeight()/8-80 + y)
			love.graphics.setShader()
		end, "replace", 1)
		love.graphics.setStencilTest("equal",1)
		love.graphics.setColor(color or {255, 0, 0, 255})
		love.graphics.draw(fireCanvas,x,y )
		love.graphics.setStencilTest()
	end,
	drawDebug = function(x,y)
		x, y = x or 0, y or 0
		x,y = x - fireCanvas:getWidth()/2, y - fireCanvas:getHeight()*.8
		love.graphics.setColor(255, 0, 0, 255)
		love.graphics.draw(partSysF, 110 + x, 6*love.graphics.getHeight()/8-80 + y)
		love.graphics.setColor(0, 255, 0, 255)
		love.graphics.draw(partSysT, 110+ x, 3*love.graphics.getHeight()/4-90 + y)
		love.graphics.setColor(0, 0, 255, 255)
		love.graphics.draw(partSysL, 20+ x, 3*love.graphics.getHeight()/4 + y)
		love.graphics.setColor(255, 255, 0, 255)
		love.graphics.draw(partSysR, 200+ x, 3*love.graphics.getHeight()/4 + y)
	end
	}
end